@@ -45,6 +45,6 @@ http_status_codes = { # source of these can be found on https://www.w3.org/Proto
 }
 
 default_headers = {
-	404: f'HTTP/1.1 404 Not Found\r\nContent-Type: application/json charset=utf-8\r\nConnection: keep-alive\r\n\r\n{json.dumps({404: "Not Found"})}'.encode(),
-	405: f'HTTP/1.1 405 Method Not Allowed\r\nContent-Type: application/json charset=utf-8\r\nConnection: keep-alive\r\n\r\n{json.dumps({405: "Method Not Allowed"})}'.encode()
+	404: f'HTTP/1.1 404 Not Found\r\nContent-Type: application/json charset=utf-8\r\n\r\n{json.dumps({404: "Not Found"})}'.encode(),
+	405: f'HTTP/1.1 405 Method Not Allowed\r\nContent-Type: application/json charset=utf-8\r\n\r\n{json.dumps({405: "Method Not Allowed"})}'.encode()
 }
\ No newline at end of file
