@@ -50,7 +50,7 @@ class Multipart:
             self.data.append(content[:-2])
             self.layout.append('data')
 
-class WebLamp:
+class Lamp:
     def __init__(self) -> None:
         self.error_handlers = {}
         self.debug = True
@@ -238,4 +238,4 @@ class WebLamp:
                     client, addr = await loop.sock_accept(s)
                     loop.create_task(self.handle(client, loop))
         
-        asyncio.run(_run())
\ No newline at end of file
+        asyncio.run(_run())
